@@ -1,4 +1,4 @@
-from typing import Any, Dict, Tuple, cast
+from typing import Any, Dict, List, Optional, Tuple, cast
 
 import httpx
 
@@ -16,14 +16,20 @@ class GetLongLivedAccessTokenError(Exception):
 
 
 class FacebookOAuth2(BaseOAuth2[Dict[str, Any]]):
-    def __init__(self, client_id: str, client_secret: str, name: str = "facebook"):
+    def __init__(
+        self,
+        client_id: str,
+        client_secret: str,
+        scopes: Optional[List[str]] = BASE_SCOPES,
+        name: str = "facebook",
+    ):
         super().__init__(
             client_id,
             client_secret,
             AUTHORIZE_ENDPOINT,
             ACCESS_TOKEN_ENDPOINT,
             name=name,
-            base_scopes=BASE_SCOPES,
+            base_scopes=scopes,
         )
 
     async def get_long_lived_access_token(self, token: str):
